Crate firewheel_nodes

Crate firewheel_nodes 

Modules

beep_test
convolution
delay_compensation
fast_filters
fast_rms
freeverb
A Rust implementation of Freeverb by Ian Hobson. The original repo can be found here.
mix
noise_generator
peak_meter
sampler
spatial_basic
A 3D spatial positioning node using a basic (and naive) algorithm. (It can also be used for 2D audio.) It does not make use of any fancy binaural algorithms, rather it just applies basic panning and filtering.
stream
svf
triple_buffer
volume
volume_pan

Structs

StereoToMonoNode
A node that converts a stereo signal into a mono signal