pub struct ConvolutionNode<const CHANNELS: usize> {
pub pause: bool,
pub mix: Mix,
pub fade_curve: FadeCurve,
pub wet_gain: Volume,
pub smooth_seconds: f32,
}Expand description
Imparts characteristics of an ImpulseResponse to the input signal.
Convolution is often used to achieve reverb effects, but is more computationally expensive than algorithmic reverb.
Fields
pause: boolPause the convolution processing.
This prevents a tail from ringing out when you want all sound to momentarily pause.
mix: MixThe value representing the mix between the two audio signals
This is a normalized value in the range [0.0, 1.0], where 0.0 is
fully the first signal, 1.0 is fully the second signal, and 0.5 is
an equal mix of both.
By default this is set to Mix::CENTER.
fade_curve: FadeCurveThe algorithm used to map the normalized mix value in the range [0.0, 1.0] to the corresponding gain values for the two signals.
By default this is set to FadeCurve::EqualPower3dB.
wet_gain: VolumeThe gain applied to the resulting convolved signal.
Defaults to -20dB to balance the volume increase likely to occur when convolving audio. Values closer to 1.0 may be very loud.
smooth_seconds: f32Adjusts the time in seconds over which parameters are smoothed for mix
and wet_gain.
Defaults to 0.015 (15ms).