pub enum PlayFrom {
Resume,
Seconds(f64),
Frames(u64),
}Expand description
Defines where the sampler should start playing from when
SamplerNode::play is set to true.
Variants
Resume
When SamplerNode::play is set to true, the sampler will resume
playing from where it last left off.
Seconds(f64)
When SamplerNode::play is set to true, the sampler will begin
playing from this position in the sample in units of seconds.
Frames(u64)
When SamplerNode::play is set to true, the sampler will begin
playing from this position in the sample in units of frames (samples
in a single channel of audio).
Implementations