Enum PlaybackState

pub enum PlaybackState {
    Stop,
    Pause,
    Play {
        delay: Option<EventDelay>,
    },
}
A parameter representing the current playback state of a sequence.

Variants



Stop

Stop the sequence.

When the sequence is started again, it will restart from the beginning.



Pause

Pause the sequence.

When the sequence is started again, it will continue from where it last left off.



Play

Play the sequence.

Fields

delay: Option<EventDelay>

The exact time at which the sequence should begin playing.

Set to None to play the sequence immediately.

Implementations