SamplerNodeResource

Enum SamplerNodeResource 

pub enum SamplerNodeResource {
    InMemory(ArcGc<dyn SampleResource + Send + Sync + 'static>),
    Streamed(OwnedGcUnsized<dyn StreamedSample>),
}
A source of audio samples for a SamplerNode.

Variants



InMemory(ArcGc<dyn SampleResource + Send + Sync + 'static>)

A resource of audio samples where the entire contents of the sample are already loaded into memory.

Prefer this for resources which are less than 20 or so seconds long (i.e. sound effects).



Streamed(OwnedGcUnsized<dyn StreamedSample>)

NOT IMPLEMENTED YET! Will lead to a panic if used.

A resource of audio samples that are streamed from disk or over a network.

Prefer this for resources which are greater than 20 or so seconds long (i.e. music tracks and ambience).

This uses considerably less memory, but requires a more complicated setup. It also has the potential to run into cache misses if the playhead is moved to a region that hasn’t been loaded yet, or if the stream fails to send enough samples in time.

Implementations

Source

impl SamplerNodeResource

pub fn from_sample<T: SampleResource + Send + Sync + 'static>(sample: T) -> Self

pub fn from_streamed<T: StreamedSample>(sample: T) -> Self

pub fn num_channels(&self) -> NonZeroUsize

The number of channels in this resource.

pub fn len_frames(&self) -> u64

The length of this resource in samples (of a single channel of audio).

Not to be confused with video frames.

pub fn sample_rate(&self) -> Option<NonZeroU32>

The sample rate of this resource.

Returns None if the sample rate is unknown.

pub fn fill_buffers( &mut self, out_buffer: &mut [&mut [f32]], out_buffer_range: Range<usize>, start_frame: u64, speed: f64, is_playing_backwards: bool, ) -> usize

Fill the given buffers with audio data starting from the given starting frame in the resource.

  • out_buffer - The buffers to fill with data. If the length of buffers is greater than the number of channels in this resource, then ignore the extra buffers.
  • out_buffer_range - The range inside each buffer slice in which to fill with data. Do not fill any data outside of this range.
  • start_frame - The sample (of a single channel of audio) in the resource at which to start copying from. Not to be confused with video frames.
  • speed - The speed at which playback is occurring, where 1.0 is playing at the sample rate of this resource, 0.5 is playing at half the sample rate, and 2.0 is playing at twice the sample rate.

Returns the number of frames that were successfully filled. This may be less than the length of out_buffer_range if the range is all or partly out of bounds of the resource, or if a cache miss occurred. Any frames that were not successfully filled will be left untouched.

pub fn range_is_ready(&mut self, range: Range<u64>) -> bool

Returns true if the given range of frames is loaded into memory and ready to be read.

pub fn cache_new_starting_frame( &mut self, frame: u64, speed: f64, will_play_backwards: bool, )

Request to cache a new region at the given starting frame.