pub struct SamplerNode {
pub sample: Option<ArcGc<dyn SampleResource>>,
pub volume: Volume,
pub play: Notify<bool>,
pub play_from: PlayFrom,
pub repeat_mode: RepeatMode,
pub speed: f64,
pub mono_to_stereo: bool,
pub crossfade_on_seek: bool,
pub min_gain: f32,
}Expand description
A node that plays samples
It supports pausing, resuming, looping, and changing the playback speed.
Fields
sample: Option<ArcGc<dyn SampleResource>>The sample resource to use.
volume: VolumeThe volume to play the sample at.
Note, this gain parameter is NOT smoothed! If you need the gain to be
smoothed, please use a VolumeNode or a VolumePanNode.
play: Notify<bool>Whether or not the current sample should start/restart playing (true), or be paused/stopped (false).
play_from: PlayFromDefines where the sampler should start playing from when
SamplerNode::play is set to true.
repeat_mode: RepeatModeHow many times a sample should be repeated.
speed: f64The speed at which to play the sample at. 1.0 means to play the sound at
its original speed, < 1.0 means to play the sound slower (which will make
it lower-pitched), and > 1.0 means to play the sound faster (which will
make it higher-pitched).
mono_to_stereo: boolIf true, then mono samples will be converted to stereo during playback.
By default this is set to true.
crossfade_on_seek: boolIf true, then samples will be crossfaded when the playhead or sample is changed (if a sample was currently playing when the event was sent).
By default this is set to true.
min_gain: f32If the resutling gain (in raw amplitude, not decibels) is less
than or equal to this value, then the gain will be clamped to
0.0 (silence).
By default this is set to 0.00001 (-100 decibels).
Implementations
Sourceimpl SamplerNode
impl SamplerNode
Sourcepub fn set_sample(&mut self, sample: ArcGc<dyn SampleResource>)
pub fn set_sample(&mut self, sample: ArcGc<dyn SampleResource>)
Set the parameters to a play a single sample.
Sourcepub fn sync_sample_event(&self) -> NodeEventType
pub fn sync_sample_event(&self) -> NodeEventType
Returns an event type to sync the sample parameter.
Sourcepub fn sync_volume_event(&self) -> NodeEventType
pub fn sync_volume_event(&self) -> NodeEventType
Returns an event type to sync the volume parameter.
Sourcepub fn sync_play_event(&self) -> NodeEventType
pub fn sync_play_event(&self) -> NodeEventType
Returns an event type to sync the play parameter.
Sourcepub fn sync_play_from_event(&self) -> NodeEventType
pub fn sync_play_from_event(&self) -> NodeEventType
Returns an event type to sync the play_from parameter.
Sourcepub fn sync_repeat_mode_event(&self) -> NodeEventType
pub fn sync_repeat_mode_event(&self) -> NodeEventType
Returns an event type to sync the playhead parameter.
Sourcepub fn sync_speed_event(&self) -> NodeEventType
pub fn sync_speed_event(&self) -> NodeEventType
Returns an event type to sync the speed parameter.
Sourcepub fn start_or_restart(&mut self)
pub fn start_or_restart(&mut self)
Start/restart the sample in this node.
If a sample is already playing, then it will restart from the beginning.
Sourcepub fn start_from(&mut self, from: PlayFrom)
pub fn start_from(&mut self, from: PlayFrom)
Play the sample in this node from the given playhead.
Sourcepub fn stop(&mut self)
pub fn stop(&mut self)
Stop sample playback.
Calling SamplerNode::resume after this will restart the sample from
the beginning.
Sourcepub fn start_or_restart_requested(&self) -> bool
pub fn start_or_restart_requested(&self) -> bool
Returns true if the current state is set to restart the sample.
Sourcepub fn resume_requested(&self) -> bool
pub fn resume_requested(&self) -> bool
Returns true if the current state is set to resume the sample.
Sourcepub fn pause_requested(&self) -> bool
pub fn pause_requested(&self) -> bool
Returns true if the current state is set to pause the sample.
Sourcepub fn stop_requested(&self) -> bool
pub fn stop_requested(&self) -> bool
Returns true if the current state is set to stop the sample.