pub struct StereoToMonoNode;Trait Implementations
Sourceimpl AudioNode for StereoToMonoNode
impl AudioNode for StereoToMonoNode
Sourcetype Configuration = EmptyConfig
type Configuration = EmptyConfig
A type representing this constructor’s configuration. Read more
Sourcefn info(&self, _config: &Self::Configuration) -> AudioNodeInfo
fn info(&self, _config: &Self::Configuration) -> AudioNodeInfo
Get information about this node. Read more
Sourcefn construct_processor(
&self,
_config: &Self::Configuration,
_cx: ConstructProcessorContext<'_>,
) -> impl AudioNodeProcessor
fn construct_processor( &self, _config: &Self::Configuration, _cx: ConstructProcessorContext<'_>, ) -> impl AudioNodeProcessor
Construct a realtime processor for this node. Read more
Sourcefn update(&mut self, configuration: &Self::Configuration, cx: UpdateContext<'_>)
fn update(&mut self, configuration: &Self::Configuration, cx: UpdateContext<'_>)
If
AudioNodeInfo::call_update_method was set to true, then the Firewheel
context will call this method on every update cycle. Read moreSourceimpl Clone for StereoToMonoNode
impl Clone for StereoToMonoNode
Sourcefn clone(&self) -> StereoToMonoNode
fn clone(&self) -> StereoToMonoNode
Returns a copy of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Component for StereoToMonoNode
impl Component for StereoToMonoNode
Sourceconst STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
const STORAGE_TYPE: StorageType = bevy_ecs::component::StorageType::Table
A constant indicating the storage type used for this component.
Sourcetype Mutability = Mutable
type Mutability = Mutable
A marker type to assist Bevy with determining if this component is
mutable, or immutable. Mutable components will have [
Component<Mutability = Mutable>],
while immutable components will instead have [Component<Mutability = Immutable>]. Read moreSourcefn register_required_components(
requiree: ComponentId,
components: &mut ComponentsRegistrator<'_>,
required_components: &mut RequiredComponents,
inheritance_depth: u16,
recursion_check_stack: &mut Vec<ComponentId>,
)
fn register_required_components( requiree: ComponentId, components: &mut ComponentsRegistrator<'_>, required_components: &mut RequiredComponents, inheritance_depth: u16, recursion_check_stack: &mut Vec<ComponentId>, )
Registers required components.
Sourcefn clone_behavior() -> ComponentCloneBehavior
fn clone_behavior() -> ComponentCloneBehavior
Called when registering this component, allowing to override clone function (or disable cloning altogether) for this component. Read more
Sourcefn register_component_hooks(hooks: &mut ComponentHooks)
fn register_component_hooks(hooks: &mut ComponentHooks)
👎Deprecated since 0.16.0: Use the individual hook methods instead (e.g.,
Component::on_add, etc.)Called when registering this component, allowing mutable access to its
ComponentHooks.Sourcefn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_add() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_insert() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_replace() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_remove() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
fn on_despawn() -> Option<for<'w> fn(DeferredWorld<'w>, HookContext)>
Sourcefn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
fn map_entities<E>(_this: &mut Self, _mapper: &mut E)where
E: EntityMapper,
Maps the entities on this component using the given
EntityMapper. This is used to remap entities in contexts like scenes and entity cloning.
When deriving Component, this is populated by annotating fields containing entities with #[entities] Read moreSourceimpl Debug for StereoToMonoNode
impl Debug for StereoToMonoNode
Sourceimpl Default for StereoToMonoNode
impl Default for StereoToMonoNode
Sourcefn default() -> StereoToMonoNode
fn default() -> StereoToMonoNode
Returns the “default value” for a type. Read more
Sourceimpl PartialEq for StereoToMonoNode
impl PartialEq for StereoToMonoNode
impl Copy for StereoToMonoNode
impl Eq for StereoToMonoNode
impl StructuralPartialEq for StereoToMonoNode