pub struct VolumeNode {
pub volume: Volume,
pub smooth_seconds: f32,
pub min_gain: f32,
}Expand description
A node that changes the volume of a signal
Fields
volume: VolumeThe volume to apply to the signal
smooth_seconds: f32The time in seconds of the internal smoothing filter.
By default this is set to 0.015 (15ms).
min_gain: f32If the resutling gain (in raw amplitude, not decibels) is less
than or equal to this value, then the gain will be clamped to
0.0 (silence).
By default this is set to 0.00001 (-100 decibels).
Implementations
Sourceimpl VolumeNode
impl VolumeNode
Sourcepub const fn from_linear(linear: f32) -> Self
pub const fn from_linear(linear: f32) -> Self
Construct a volume node from the given volume in a linear scale,
where 0.0 is silence and 1.0 is unity gain.
These units are suitable for volume sliders (simply convert percent volume to linear volume by diving the percent volume by 100).
Sourcepub const fn from_percent(percent: f32) -> Self
pub const fn from_percent(percent: f32) -> Self
Construct a volume node from the given volume in percentage,
where 0.0 is silence and 100.0 is unity gain.
These units are suitable for volume sliders.
Sourcepub const fn from_decibels(decibels: f32) -> Self
pub const fn from_decibels(decibels: f32) -> Self
Construct a volume node from the given volume in decibels, where 0.0
is unity gain and f32::NEG_INFINITY is silence.
Sourcepub const fn set_linear(&mut self, linear: f32)
pub const fn set_linear(&mut self, linear: f32)
Set the given volume in a linear scale, where 0.0 is silence and
1.0 is unity gain.
These units are suitable for volume sliders (simply convert percent volume to linear volume by diving the percent volume by 100).
Sourcepub const fn set_percent(&mut self, percent: f32)
pub const fn set_percent(&mut self, percent: f32)
Set the given volume in percentage, where 0.0 is silence and
100.0 is unity gain.
These units are suitable for volume sliders.
Sourcepub const fn set_decibels(&mut self, decibels: f32)
pub const fn set_decibels(&mut self, decibels: f32)
Set the given volume in decibels, where 0.0 is unity gain and
f32::NEG_INFINITY is silence.