A 3D spatial positioning node using a basic (and naive) algorithm. (It can also be used for 2D audio.) It does not make use of any fancy binaural algorithms, rather it just applies basic panning and filtering.
Structs
- Spatial
Basic Node - A 3D spatial positioning node using a basic but fast algorithm. (It can also be used for 2D audio). It does not make use of any fancy binaural algorithms, rather it just applies basic panning and filtering.
Enums
- Spatial
Basic Node Patch - The patch enum for
SpatialBasicNode, generated by Firewheel’sPatchderive macro.