Module spatial_basic

Module spatial_basic 

A 3D spatial positioning node using a basic (and naive) algorithm. It does not make use of any fancy binaural algorithms, rather it just applies basic panning and filtering.

Structs

SpatialBasicNode
The parameters for a 3D spatial positioning node using a basic (and naive) algorithm. It does not make use of any fancy binaural algorithms, rather it just applies basic panning and filtering.

Enums

SpatialBasicNodePatch
The patch enum for SpatialBasicNode, generated by Firewheel’s Patch derive macro.